@@ -4,6 +4,8 @@ from typing import Optional
 
 import pandas as pd
 
+from icdpicpy.src.datamodel import Table
+
 
 class DataRepository:
     def __init__(self):
@@ -21,7 +23,7 @@ class DataRepository:
         self.__logger.debug(f'read {len(patient_code_dict)} patients')
         return patient_code_dict
 
-    def read_data_file(self, file_name: str) -> Optional[pd.DataFrame]:
+    def read_data_file(self, file_name: str, sep=',') -> Optional[pd.DataFrame]:
         self.__logger.debug(f'read file "{file_name}"')
         data_path = f'{os.path.dirname(__file__)}/../../data'
         file_name = f'{data_path}/{file_name}'
@@ -29,7 +31,9 @@ class DataRepository:
             self.__logger.error(f'can not find file : {file_name}')
             return None
         try:
-            df = pd.read_csv(file_name)
+            df = pd.read_csv(file_name, sep=sep)
+            if Table.BaseColumns.code in df.columns:
+                df[Table.BaseColumns.code] = df[Table.BaseColumns.code].astype(str)
             return df
         except Exception as e:
             self.__logger.error(e)
